@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2017 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2018 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -391,13 +391,12 @@ class ConfigServer(object):
         self.connections = OptionNumber(name, 'connections', 1, 0, 100, add=False)
         self.ssl = OptionBool(name, 'ssl', False, add=False)
         self.ssl_verify = OptionNumber(name, 'ssl_verify', 2, add=False)  # 0=No, 1=Normal, 2=Strict (hostname verification)
+        self.ssl_ciphers = OptionStr(name, 'ssl_ciphers', '', add=False)
         self.enable = OptionBool(name, 'enable', True, add=False)
         self.optional = OptionBool(name, 'optional', False, add=False)
         self.retention = OptionNumber(name, 'retention', add=False)
         self.send_group = OptionBool(name, 'send_group', False, add=False)
         self.priority = OptionNumber(name, 'priority', 0, 0, 99, add=False)
-        # 'fillserver' field only here in order to set a proper priority when converting
-        self.fillserver = OptionBool(name, 'fillserver', False, add=False)
         self.notes = OptionStr(name, 'notes', '', add=False)
 
         self.set_dict(values)
@@ -405,15 +404,15 @@ class ConfigServer(object):
 
     def set_dict(self, values):
         """ Set one or more fields, passed as dictionary """
-        for kw in ('displayname', 'host', 'port', 'timeout', 'username', 'password', 'connections', 'fillserver',
-                   'ssl', 'ssl_verify', 'send_group', 'enable', 'optional', 'retention', 'priority', 'notes'):
+        for kw in ('displayname', 'host', 'port', 'timeout', 'username', 'password', 'connections', 'ssl',
+                   'ssl_verify', 'ssl_ciphers', 'send_group', 'enable', 'optional', 'retention', 'priority', 'notes'):
             try:
                 value = values[kw]
             except KeyError:
                 continue
             exec 'self.%s.set(value)' % kw
-            if not self.displayname():
-                self.displayname.set(self.__name)
+        if not self.displayname():
+            self.displayname.set(self.__name)
         return True
 
     def get_dict(self, safe=False):
@@ -432,6 +431,7 @@ class ConfigServer(object):
         dict['connections'] = self.connections()
         dict['ssl'] = self.ssl()
         dict['ssl_verify'] = self.ssl_verify()
+        dict['ssl_ciphers'] = self.ssl_ciphers()
         dict['enable'] = self.enable()
         dict['optional'] = self.optional()
         dict['retention'] = self.retention()
@@ -463,7 +463,7 @@ class ConfigCat(object):
         self.pp = OptionStr(name, 'pp', '', add=False)
         self.script = OptionStr(name, 'script', 'Default', add=False)
         self.dir = OptionDir(name, 'dir', add=False, create=False)
-        self.newzbin = OptionList(name, 'newzbin', add=False)
+        self.newzbin = OptionList(name, 'newzbin', add=False, validation=validate_single_tag)
         self.priority = OptionNumber(name, 'priority', DEFAULT_PRIORITY, add=False)
 
         self.set_dict(values)
@@ -877,13 +877,16 @@ def define_servers():
         for server in CFG['servers']:
             svr = CFG['servers'][server]
             s = ConfigServer(server.replace('{', '[').replace('}', ']'), svr)
-            if s.fillserver():
-                # One time conversion of backup to priority 1
-                s.priority.set(1)
-                s.fillserver.set(False)
+
+            # Conversion of global SSL-Ciphers to server ones
+            if sabnzbd.cfg.ssl_ciphers():
+                s.ssl_ciphers.set(sabnzbd.cfg.ssl_ciphers())
     except KeyError:
         pass
 
+    # No longer needed
+    sabnzbd.cfg.ssl_ciphers.set('')
+
 
 def get_servers():
     global database
@@ -893,7 +896,7 @@ def get_servers():
         return {}
 
 
-def define_categories(force=False):
+def define_categories():
     """ Define categories listed in the Setup file
         return a list of ConfigCat instances
     """
@@ -987,7 +990,7 @@ def get_rss():
             for feed_uri in feed.uri():
                 if new_feed_uris and not urlparse(feed_uri).scheme and urlparse(new_feed_uris[-1]).scheme:
                     # Current one has no scheme but previous one does, append to previous
-                    new_feed_uris[-1] += '%2C' + feed_uri
+                    new_feed_uris[-1] += ',' + feed_uri
                     have_new_uri = True
                     continue
                 # Add full working URL
@@ -1051,6 +1054,14 @@ def no_nonsense(value):
     return None, value
 
 
+def all_lowercase(value):
+    """ Lowercase everything! """
+    if isinstance(value, list):
+        # If list, for each item
+        return None, [item.lower() for item in value]
+    return None, value.lower()
+
+
 def validate_octal(value):
     """ Check if string is valid octal number """
     if not value:
@@ -1091,6 +1102,16 @@ def validate_notempty(root, value, default):
         return None, default
 
 
+def validate_single_tag(value):
+    """ Don't split single indexer tags like "TV > HD"
+        into ['TV', '>', 'HD']
+    """
+    if len(value) == 3:
+        if value[1] == '>':
+            return None, ' '.join(value)
+    return None, value
+
+
 def create_api_key():
     """ Return a new randomized API_KEY """
     # Create some values to seed md5
